==> 5.7.0.tar.gz: hugo-theme-relearn/README.md <==
# Hugo Relearn Theme

A theme for [Hugo](https://gohugo.io/) designed for documentation.

![Overview](https://github.com/McShelby/hugo-theme-relearn/raw/main/images/screenshot.png)

## Motivation

The theme is a fork of the great [Learn theme](https://github.com/matcornic/hugo-theme-learn) with the aim of fixing long outstanding bugs and adepting to latest Hugo features. As far as possible this theme tries to be a drop-in replacement for the Learn theme.

## Main features

- Usable offline, no external dependencies
- Usable without a HTTP server from the file system
- Support for Internet Explorer 11
- Responsive design
- Configurable hidden pages
- Automatic next/prev buttons to navigate through menu entries
- Automatic Search
- Dedicated search page
- Print whole chapters or even the complete site
- Multilingual mode for English, Arabic, Simplified Chinese, Traditional Chinese, Dutch, Finnish (Suomi), French, German, Hindi, Indonesian, Italian, Japanese, Korean, Polish, Portuguese, Russian, Spanish, Turkish, Vietnamese
- Support for languages written right to left
- Unrestricted menu configuration relating to amount of items and level of nesting
- Font Awesome icons
- Tagging support
- Image resizing, shadow…
- Syntax highlighting
- Attachments files
- List child pages
- Math and chemical formulae using the MathJax library
- Mermaid diagrams for flowcharts, sequences, gantts, pie, etc.
- Swagger UI for OpenAPI Specifications
- Customizable look and feel
- Predefined (light, dark) and customizable color variants
- Buttons
- Tip/Note/Info/Warning boxes
- Expand
- Tabs
- File inclusion
## Installation

Visit the [installation instructions](https://mcshelby.github.io/hugo-theme-relearn/basics/installation) to learn how to setup the theme in your Hugo installation.

## Usage

Visit the [documentation](https://mcshelby.github.io/hugo-theme-relearn/) to learn about all available features and how to use them.

## Changelog

See the [changelog](https://mcshelby.github.io/hugo-theme-relearn/basics/history) for a complete list of releases.

## Contribution

You are most welcome to contribute to the source code but please visit the [contribution guidelines](https://github.com/McShelby/hugo-theme-relearn/blob/main/.github/contributing.md) first.

## License

This theme is licensed under the [MIT License](https://github.com/McShelby/hugo-theme-relearn/blob/main/LICENSE).

## Credits

Special thanks to [everyone who has contributed](https://github.com/McShelby/hugo-theme-relearn/graphs/contributors) to this project.

Many thanks to [Mathieu Cornic](https://github.com/matcornic) for his work on porting the [Learn theme](https://github.com/matcornic/hugo-theme-learn) to Hugo.

Many thanks to [Andy Miller](https://github.com/rhukster) for initially creating the [Learn theme](https://github.com/getgrav/grav-theme-learn2) for Grav.

==> 5.9.4.tar.gz: hugo-theme-relearn/README.md <==
# Hugo Relearn Theme

A theme for [Hugo](https://gohugo.io/) designed for documentation.

![Overview](https://github.com/McShelby/hugo-theme-relearn/raw/main/images/screenshot.png)

## Motivation

The theme is a fork of the great [Learn theme](https://github.com/matcornic/hugo-theme-learn) with the aim of fixing long outstanding bugs and adepting to latest Hugo features. As far as possible this theme tries to be a drop-in replacement for the Learn theme.

## Features

- Usable offline, no external dependencies
- Usable without a HTTP server from the file system
- Support for Internet Explorer 11
- Responsive design
- Configurable hidden pages
- Automatic next/prev buttons to navigate through menu entries
- Automatic Search
- Dedicated search page
- Support for GFM (GitHub Flavored Markdown)
- Print whole chapters or even the complete site
- Multilingual mode for English, Arabic, Simplified Chinese, Traditional Chinese, Dutch, Finnish (Suomi), French, German, Hindi, Indonesian, Italian, Japanese, Korean, Polish, Portuguese, Russian, Spanish, Turkish, Vietnamese
- Support for languages written right to left
- Unrestricted menu configuration relating to amount of items and level of nesting
- Font Awesome icons
- Tagging support
- Image styling like sizing, shadow, border and alignment
- Syntax highlighting
- Customizable look and feel
- Predefined (light, dark) and customizable color variants
- Attachments files
- List child pages
- Math and chemical formulae using the MathJax library
- Mermaid diagrams for flowcharts, sequences, gantts, pie, etc.
- Swagger UI for OpenAPI Specifications
- Badges
- Buttons
- Tip/Note/Info/Warning boxes
- Expand
- Tabs
- File inclusion

## Installation

Visit the [installation instructions](https://mcshelby.github.io/hugo-theme-relearn/basics/installation) to learn how to setup the theme in your Hugo installation.

## Usage

Visit the [documentation](https://mcshelby.github.io/hugo-theme-relearn/) to learn about all available features and how to use them.

## Changelog

See the [What's New](https://mcshelby.github.io/hugo-theme-relearn/basics/migration) page for release highlights or the [history](https://mcshelby.github.io/hugo-theme-relearn/basics/history) for a complete list of changes per release.

## Contribution

You are most welcome to contribute bugfixes or even new features to the source code. Please visit the [contribution guidelines](https://github.com/McShelby/hugo-theme-relearn/blob/main/.github/contributing.md) first.

## License

This theme is licensed under the [MIT License](https://github.com/McShelby/hugo-theme-relearn/blob/main/LICENSE).

## Credits

Special thanks to [everyone who has contributed](https://github.com/McShelby/hugo-theme-relearn/graphs/contributors) to this project.

Many thanks to [Mathieu Cornic](https://github.com/matcornic) for his work on porting the [Learn theme](https://github.com/matcornic/hugo-theme-learn) to Hugo.

Many thanks to [Andy Miller](https://github.com/rhukster) for initially creating the [Learn theme](https://github.com/getgrav/grav-theme-learn2) for Grav.

See the [credits](https://mcshelby.github.io/hugo-theme-relearn/more/credits) for a detailed list.
